@@ -1,7 +1,7 @@
-import PyPDF2
 import textract
 import os
 from glob import glob
+import re
 
 
 class TextExtractor:
@@ -24,12 +24,34 @@ class TextExtractor:
         if os.path.basename(path).endswith(".txt"):
             return path
         output_path = self.get_output_path(path)
-        text = textract.process(path).decode("utf-8")
         self.logger.info("Extract text from {} to {}".format(path, output_path))
+        text = textract.process(path).decode("utf-8")
         with open(output_path, "w") as f:
             f.write(text)
         return output_path
 
+    def extract_from_pdf_file(self, path):
+        output_path = self.get_output_path(path)
+        self.logger.info("Extract text from {} to {}".format(path, output_path))
+        text = textract.process(path, method="pdfminer").decode("utf-8")
+        text = self.post_processing(text)
+        with open(output_path, "w") as f:
+            f.write(text)
+        return output_path
+
+    def post_processing(self, text):
+        # Replace \t by whitespace
+        text = re.sub("\t+", " ", text)
+        # Remove word break
+        text = re.sub("-\n", "", text)
+        # Remove newline characters in paragraphs
+        text = re.sub("(?<!\n)\n(?!\n)", " ", text)
+        # Remove multiple whitespaces
+        text = re.sub(" +", " ", text)
+        # Remove trailing newlines
+        text = text.strip(" \n")
+        return text
+
     def get_output_path(self, path):
         tokens = os.path.basename(path).split(".")
         if len(tokens):
